==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/pt-PT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Acessório recebido',
    'Accessory_Checkout_Notification' => 'Acessório verificado',
    'Asset_Checkin_Notification' => 'Artigos recebidos',
    'Asset_Checkout_Notification' => 'Artigos entregues',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_Asset_Checkin' => 'Confirmação da devolução do artigo',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_asset_delivery' => 'Confirmação de entrega do artigo',
    'Confirm_consumable_delivery' => 'Confirmação de entrega do consumível',
    'Confirm_license_delivery' => 'Confirmação de entrega de licença',
    'Consumable_checkout_notification' => 'Consumível verificado',
    'Days' => 'Dias',
    'Expected_Checkin_Date' => 'Um ativo entregue a si deve ser entregue até :date',
    'Expected_Checkin_Notification' => 'Lembrete: :name entrega com prazo aproximado',
    'Expected_Checkin_Report' => 'Relatório de entregas de artigos esperados',
    'Expiring_Assets_Report' => 'Relatório de artigos a expirar.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'License_Checkin_Notification' => 'Licença recebida',
    'License_Checkout_Notification' => 'Licença registrada',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'a_user_canceled' => 'Um utilizador cancelou um pedido de artigo no site',
    'a_user_requested' => 'Um utilizador solicitou um artigo no site',
    'acceptance_asset_accepted' => 'Um usuário aceitou um item',
    'acceptance_asset_declined' => 'Um usuário recusou um item',
    'accessory_name' => 'Nome do acessório:',
    'additional_notes' => 'Notas adicionais:',
    'admin_has_created' => 'Um administrador criou uma conta para ti no :web site.',
    'asset' => 'Artigo:',
    'asset_name' => 'Nome do Artigo:',
    'asset_requested' => 'Artigo requesitado',
    'asset_tag' => 'Etiqueta do Ativo',
    'assets_warrantee_alert' => 'Existe :count artigo com a garantia a expirar nos próximos :threshold dias.|Existem :count artigos com a garantia a expirar nos próximos :threshold dias.',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Data de devolução:',
    'checkout_date' => 'Data de atribuição:',
    'checkedout_from' => 'Check-out de',
    'checkedin_from'  => 'Check-in de',
    'checked_into' => 'Check-in em',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o artigo.',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'current_QTY' => 'qtde. actual',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data prevista de devolução:',
    'expires' => 'Expira a',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'inventory_report' => 'Relatório de Inventário',
    'item' => 'Item:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Há :count licença a expirar nos próximos :threshold dias. Existem :count licenças que irão expirar nos próximos :threshold dias.',
    'link_to_update_password' => 'Por favor clique no link abaixo para actualizar a sua senha do :web:',
    'login' => 'Login:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'low_inventory_alert' => 'Há :count que está abaixo do estoque mínimo ou em breve estará baixo. Existem :count itens que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'min_QTY' => 'Qt. Min.',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi atribuído a ti, os detalhes estão abaixo.',
    'notes' => 'Notas',
    'password' => 'Senha:',
    'password_reset' => 'Repor senha',
    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo, e clique no link na parte inferior para confirmar que você leu e concorda com os termos de uso, e recebeu o ativo.',
    'requested' => 'Requisitado:',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir a sua password:',
    'rights_reserved' => 'Todos os direitos reservados.',
    'serial' => 'Nº de Série',
    'snipe_webhook_test' => 'Teste de Integração Snipe-IT',
    'snipe_webhook_summary' => 'Resumo de Teste de Integração Snipe-IT',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um email de teste do Snipe-IT Asset Management System. Se recebeste o recebeste, quer dizer que o email está a funcionar :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'to_reset' => 'Para fazer reset a senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está a chegar para ser auditado em :threshold dias.|Existem :count ativos que estão a chegar para serem auditados em :threshold dias.',
    'user' => 'Utilizador',
    'username' => 'Nome de utilizador',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Bem vindo, :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_assets' => 'Ver seus ativos',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/pt-PT/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Acessório recebido',
    'Accessory_Checkout_Notification' => 'Acessório verificado',
    'Asset_Checkin_Notification' => 'Artigos recebidos',
    'Asset_Checkout_Notification' => 'Artigos entregues',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_Asset_Checkin' => 'Confirmação da devolução do artigo',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_asset_delivery' => 'Confirmação de entrega do artigo',
    'Confirm_consumable_delivery' => 'Confirmação de entrega do consumível',
    'Confirm_license_delivery' => 'Confirmação de entrega de licença',
    'Consumable_checkout_notification' => 'Consumível verificado',
    'Days' => 'Dias',
    'Expected_Checkin_Date' => 'Um ativo entregue a si deve ser entregue até :date',
    'Expected_Checkin_Notification' => 'Lembrete: :name entrega com prazo aproximado',
    'Expected_Checkin_Report' => 'Relatório de entregas de artigos esperados',
    'Expiring_Assets_Report' => 'Relatório de artigos a expirar.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'License_Checkin_Notification' => 'Licença recebida',
    'License_Checkout_Notification' => 'Licença registrada',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'a_user_canceled' => 'Um utilizador cancelou um pedido de artigo no site',
    'a_user_requested' => 'Um utilizador solicitou um artigo no site',
    'acceptance_asset_accepted' => 'Um usuário aceitou um item',
    'acceptance_asset_declined' => 'Um usuário recusou um item',
    'accessory_name' => 'Nome do Acessório',
    'additional_notes' => 'Notas adicionais',
    'admin_has_created' => 'Um administrador criou uma conta para ti no :web site.',
    'asset' => 'Ativo',
    'asset_name' => 'Nome do Ativo',
    'asset_requested' => 'Artigo requesitado',
    'asset_tag' => 'Etiqueta do Ativo',
    'assets_warrantee_alert' => 'Existe :count artigo com a garantia a expirar nos próximos :threshold dias.|Existem :count artigos com a garantia a expirar nos próximos :threshold dias.',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente',
    'canceled' => 'Cancelado',
    'checkin_date' => 'Data de devolução',
    'checkout_date' => 'Data de alocação',
    'checkedout_from' => 'Check-out de',
    'checkedin_from'  => 'Check-in de',
    'checked_into' => 'Check-in em',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o artigo.',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'current_QTY' => 'qtde. actual',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data de devolução esperada',
    'expires' => 'Expira a',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'inventory_report' => 'Relatório de Inventário',
    'item' => 'Item',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Há :count licença a expirar nos próximos :threshold dias. Existem :count licenças que irão expirar nos próximos :threshold dias.',
    'link_to_update_password' => 'Por favor clique no link abaixo para actualizar a sua senha do :web:',
    'login' => 'Login:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'low_inventory_alert' => 'Há :count que está abaixo do estoque mínimo ou em breve estará baixo. Existem :count itens que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'min_QTY' => 'Qt. Min.',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi atribuído a ti, os detalhes estão abaixo.',
    'notes' => 'Notas',
    'password' => 'Password',
    'password_reset' => 'Repor senha',
    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo, e clique no link na parte inferior para confirmar que você leu e concorda com os termos de uso, e recebeu o ativo.',
    'requested' => 'Solicitado',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir a sua password:',
    'rights_reserved' => 'Todos os direitos reservados.',
    'serial' => 'Nº de Série',
    'snipe_webhook_test' => 'Teste de Integração Snipe-IT',
    'snipe_webhook_summary' => 'Resumo de Teste de Integração Snipe-IT',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um email de teste do Snipe-IT Asset Management System. Se recebeste o recebeste, quer dizer que o email está a funcionar :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'to_reset' => 'Para fazer reset a senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está a chegar para ser auditado em :threshold dias.|Existem :count ativos que estão a chegar para serem auditados em :threshold dias.',
    'user' => 'Utilizador',
    'username' => 'Nome de utilizador',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Bem vindo, :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_assets' => 'Ver seus ativos',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
